/*******************************************************************************
* Copyright (C) 2019 China Micro Semiconductor Limited Company. All Rights Reserved.
*
* This software is owned and published by:
* CMS LLC, No 2609-10, Taurus Plaza, TaoyuanRoad, NanshanDistrict, Shenzhen, China.
*
* BY DOWNLOADING, INSTALLING OR USING THIS SOFTWARE, YOU AGREE TO BE BOUND
* BY ALL THE TERMS AND CONDITIONS OF THIS AGREEMENT.
*
* This software contains source code for use with CMS
* components. This software is licensed by CMS to be adapted only
* for use in systems utilizing CMS components. CMS shall not be
* responsible for misuse or illegal use of this software for devices not
* supported herein. CMS is providing this software "AS IS" and will
* not be responsible for issues arising from incorrect user implementation
* of the software.
*
* This software may be replicated in part or whole for the licensed use,
* with the restriction that this Disclaimer and Copyright notice must be
* included with each copy of this software, whether used in part or whole,
* at all times.
*/

/****************************************************************************/
/** \file bsp_sigmadelta_adc.c
**
**  
**
**	History:
**	
*****************************************************************************/
/****************************************************************************/
/*	include files
*****************************************************************************/
#include "bsp_sigmadelta_adc.h"

/****************************************************************************/
/*	Local pre-processor symbols/macros('#define')
*****************************************************************************/

/****************************************************************************/
/*	Global variable definitions(declared in header file with 'extern')
*****************************************************************************/

/****************************************************************************/
/*	Local type definitions('typedef')
*****************************************************************************/

/****************************************************************************/
/*	Local variable  definitions('static')
*****************************************************************************/

/****************************************************************************/
/*	Local function prototypes('static')
*****************************************************************************/
/******************************************************************************
 ** \brief	 SigmaDeltaADCDelay
 **			 
 ** \param [in] none
 ** \return  none
 ** \note   
*****************************************************************************/
static  void  SigmaDeltaADCDelay(uint8_t num)
{
	do{
		_nop_();			//（1个指令周期+ 1个判断指令） *num   +跳转+返回  
		_nop_();					//= 2 *num +2 条指令周期 = （8*num+8）/Fsys 
		_nop_();
		_nop_();
		_nop_();
		_nop_();			//1us :48Mhz 约6个nop    24Mhz 约3个nop
	}while(num--);
}

/****************************************************************************/
/*	Function implementation - global ('extern') and local('static')
*****************************************************************************/
/******************************************************************************
 ** \brief	 SigmaDeltaADCInit
 **			 
 ** \param [in] none
 ** \return  none
 ** \note   
*****************************************************************************/
void SigmaDeltaADCInit(void)
{
	//P04 SCK   P05:DOUT
	//P05默认为高电平，低电平为表示准备就绪
	
	P05CFG = 0x00;
	P0TRIS &=~(1<<5);
	
	P04CFG = 0x00;
	P04 = 0;			//SCK =0，处于正常工作模式		
	P0TRIS |=(1<<4);	
	
	P0RD |=(1<<4);	//P04开下拉
	P0UP |=(1<<5);	//P05 开上拉	
	
	//开启P05的下降沿中断模式
	P05EICFG = 0x2;
	P0EXTIE |=(1<<5);
	EIP1 = 0x1;
	
}

/******************************************************************************
 ** \brief	 SigmaDeltaADCEnterSleep
 **			 进入低功耗模式
 ** \param [in] none
 ** \return  none
 ** \note   
*****************************************************************************/
void SigmaDeltaADCEnterSleep(void)
{	
	SCK_CLR;
	SigmaDeltaADCDelay(4);
	SCK_SET;							
	SigmaDeltaADCDelay(250);		//拉高后延时大于100us进入低功耗模式
	SigmaDeltaADCDelay(250);	
	SigmaDeltaADCDelay(250);	
	SigmaDeltaADCDelay(250);
	SigmaDeltaADCDelay(250);
	SigmaDeltaADCDelay(250);
	SigmaDeltaADCDelay(250);
	SigmaDeltaADCDelay(250);
	SigmaDeltaADCDelay(250);
	SigmaDeltaADCDelay(250);
	SigmaDeltaADCDelay(250);
}

/******************************************************************************
 ** \brief	 SigmaDeltaADCWork
**			 正常工作模式
 ** \param [in] none
 ** \return  none
 ** \note   
*****************************************************************************/
void SigmaDeltaADCWork(void)
{
	SCK_CLR;
	SigmaDeltaADCDelay(250);
	SigmaDeltaADCDelay(250);
	SigmaDeltaADCDelay(250);
}

/******************************************************************************
 ** \brief	 SigmaDeltaCheckReady
 **			  数据检测
 ** \param [in] delay：延时时间
 ** \return  0：检测到有效电平  1：延时时间内未检测到有效电平
 ** \note   
*****************************************************************************/
uint8_t SigmaDeltaCheckReady(uint16_t delay)
{	
	uint16_t count;
	count =0;
    ADC_SDA_INPUT_MODE();	
	SigmaDeltaADCDelay(SCK_DELAY_US);
	
	do{
		if(DOUT_IS_LOW)
		{
			count ++;
		}		
		if(count > ADC_CHECK_CNT )		//检测有效次数
			return 0;
		SigmaDeltaADCDelay(SCK_DELAY_US);
	}while(delay--);
	
	return 1;
}

/******************************************************************************
 ** \brief	 SigmaDeltaWaitReady
 **			  数据检测(强制等待)
 ** \param [in] none
 ** \return none
 ** \note   
*****************************************************************************/
void SigmaDeltaWaitReady(void)
{	
    ADC_SDA_INPUT_MODE();
	
	SigmaDeltaADCDelay(SCK_DELAY_US);		
	/*----DOUT is LOW------*/
	if(DOUT_IS_LOW)
	{
		while(DOUT_IS_LOW);	
		//DOUT is High		
		while(DOUT_IS_HIGH);
		//DOUT is LOW	
	}
	else
	{
		while(DOUT_IS_HIGH);		//强制等待
	}
}

/******************************************************************************
 ** \brief	 SigmaDeltaAdcWriteReg
 **			 写配置
 ** \param [in] cmd: 命令字节
**				dat: 数据
 ** \return  24位ADC数据
 ** \note  
*****************************************************************************/
uint32_t SigmaDeltaAdcWriteReg(uint8_t cmd, uint8_t dat)
{

	uint8_t i;
	uint32_t  data1;
	data1 =0;
	for(i=0;i<24;i++) 
	{
		SCK_SET; 			
		SigmaDeltaADCDelay(SCK_DELAY_US);	
		SCK_CLR;
		SigmaDeltaADCDelay(SCK_DELAY_US);	
		data1 = data1<<1;	
		if(DOUT_IS_HIGH) 
			data1 |= 1; 		
	}		
		
	/*延时*/
    SigmaDeltaADCDelay(SCK_DELAY_US);
    SigmaDeltaADCDelay(SCK_DELAY_US);	
	/* 第25个CLK*/
	SCK_SET; 			
	SigmaDeltaADCDelay(SCK_DELAY_US);	
	SCK_CLR;
	SigmaDeltaADCDelay(SCK_DELAY_US);			

	/* 第26个CLK*/
	SCK_SET; 			
	SigmaDeltaADCDelay(SCK_DELAY_US);	
	SCK_CLR;
	SigmaDeltaADCDelay(SCK_DELAY_US);	
	/*延时*/
    SigmaDeltaADCDelay(SCK_DELAY_US);
    SigmaDeltaADCDelay(SCK_DELAY_US);
	
	/* 第27个CLK*/
	SCK_SET; 			
	SigmaDeltaADCDelay(SCK_DELAY_US);	
	SCK_CLR;
	SigmaDeltaADCDelay(SCK_DELAY_US);			
	/*延时*/
    SigmaDeltaADCDelay(SCK_DELAY_US);
    SigmaDeltaADCDelay(SCK_DELAY_US);

	//第28个CLK
	SCK_SET; 			
	SigmaDeltaADCDelay(SCK_DELAY_US);	
	SCK_CLR;
	SigmaDeltaADCDelay(SCK_DELAY_US);		
	//第29个CLK
	SCK_SET; 			
	SigmaDeltaADCDelay(SCK_DELAY_US);	
	SCK_CLR;
	SigmaDeltaADCDelay(SCK_DELAY_US);		
	
	//切换DOUT为输出
    ADC_SDA_OUTPUT_MODE();

    SigmaDeltaADCDelay(SCK_DELAY_US);
    SigmaDeltaADCDelay(SCK_DELAY_US);

	//发送7位命令，高位在前
	cmd = cmd<<1;
	for(i=0;i<7;i++)
	{				
		if(cmd&0x80)
		{
			DOUT_SET;
		}
		else
		{
			DOUT_CLR;
		}
		cmd = cmd<<1;
		
		SCK_SET; 			
		SigmaDeltaADCDelay(SCK_DELAY_US);	
		SCK_CLR;
		SigmaDeltaADCDelay(SCK_DELAY_US);			
		
	}
	
	SigmaDeltaADCDelay(SCK_DELAY_US);
    SigmaDeltaADCDelay(SCK_DELAY_US);	
	//37 CLK	
	SCK_SET; 			
	SigmaDeltaADCDelay(SCK_DELAY_US);	
	SCK_CLR;
	SigmaDeltaADCDelay(SCK_DELAY_US);			
	
	SigmaDeltaADCDelay(SCK_DELAY_US);
    SigmaDeltaADCDelay(SCK_DELAY_US);
	
	//发送8位数据，高位在前
	
	for(i=0;i<8;i++)//38~45
	{
		if(dat&0x80)
		{
			DOUT_SET;
		}
		else
		{
			DOUT_CLR;
		}
		dat = dat<<1;	
		SCK_SET; 			
		SigmaDeltaADCDelay(SCK_DELAY_US);	
		SCK_CLR;
		SigmaDeltaADCDelay(SCK_DELAY_US);					
	}
   
    SigmaDeltaADCDelay(SCK_DELAY_US);
    SigmaDeltaADCDelay(SCK_DELAY_US);

	//设置DOUT 输入
	ADC_SDA_INPUT_MODE();
	
	//46 CLK
	SCK_SET; 			
	SigmaDeltaADCDelay(SCK_DELAY_US);	
	SCK_CLR;
	SigmaDeltaADCDelay(SCK_DELAY_US);		
		
	return data1;   
}
/******************************************************************************
 ** \brief	 SigmaDeltaAdcReadReg
 **			 配置读取
 ** \param [in] cmd : 命令字节
 ** \return  配置数据
 ** \note  
*****************************************************************************/
uint8_t SigmaDeltaAdcReadReg(uint8_t cmd)
{
	uint8_t i,dat;
	dat =0;
	for(i=0;i<24;i++) 
	{
		SCK_SET; 			
		SigmaDeltaADCDelay(SCK_DELAY_US);	
		SCK_CLR;
		SigmaDeltaADCDelay(SCK_DELAY_US);					
	}	
    	
    SigmaDeltaADCDelay(SCK_DELAY_US);
    SigmaDeltaADCDelay(SCK_DELAY_US);

	/* 第25个CLK*/
	SCK_SET; 			
	SigmaDeltaADCDelay(SCK_DELAY_US);	
	SCK_CLR;
	SigmaDeltaADCDelay(SCK_DELAY_US);	
	/* 第26个CLK*/
	SCK_SET; 			
	SigmaDeltaADCDelay(SCK_DELAY_US);	
	SCK_CLR;
	SigmaDeltaADCDelay(SCK_DELAY_US);	

    SigmaDeltaADCDelay(SCK_DELAY_US);
    SigmaDeltaADCDelay(SCK_DELAY_US);

	/* 第27个CLK*/
	SCK_SET; 			
	SigmaDeltaADCDelay(SCK_DELAY_US);	
	SCK_CLR;
	SigmaDeltaADCDelay(SCK_DELAY_US);			
	/*延时*/
    SigmaDeltaADCDelay(SCK_DELAY_US);
    SigmaDeltaADCDelay(SCK_DELAY_US);	

	//第28个CLK
	SCK_SET; 			
	SigmaDeltaADCDelay(SCK_DELAY_US);	
	SCK_CLR;
	SigmaDeltaADCDelay(SCK_DELAY_US);		
	//第29个CLK
	SCK_SET; 			
	SigmaDeltaADCDelay(SCK_DELAY_US);	
	SCK_CLR;
	SigmaDeltaADCDelay(SCK_DELAY_US);	
		
    ADC_SDA_OUTPUT_MODE();

    SigmaDeltaADCDelay(SCK_DELAY_US);
    SigmaDeltaADCDelay(SCK_DELAY_US);

	//发送7位命令，高位在前
	cmd = cmd<<1;
	for(i=0;i<7;i++)
	{

		if(cmd&0x80)
		{
			DOUT_SET;
		}
		else
		{
			DOUT_CLR;
		}
		cmd = cmd<<1;
		SCK_SET; 			
		SigmaDeltaADCDelay(SCK_DELAY_US);	
		SCK_CLR;
		SigmaDeltaADCDelay(SCK_DELAY_US);		
	}
    
	SigmaDeltaADCDelay(SCK_DELAY_US);
    SigmaDeltaADCDelay(SCK_DELAY_US);
	
	//第37个CLK
	SCK_SET; 			
	SigmaDeltaADCDelay(SCK_DELAY_US);	
	SCK_CLR;
	SigmaDeltaADCDelay(SCK_DELAY_US);			

    ADC_SDA_INPUT_MODE();	
	
    SigmaDeltaADCDelay(SCK_DELAY_US);
    SigmaDeltaADCDelay(SCK_DELAY_US);
    
	//读取8位数据
	for(i=0;i<8;i++)
	{
		SCK_SET; 			
		SigmaDeltaADCDelay(SCK_DELAY_US);	
		SCK_CLR;
		SigmaDeltaADCDelay(SCK_DELAY_US);		
		
		dat = dat<<1;	
		if(DOUT_IS_HIGH) 
			dat |= 1;    
	}
		
    SigmaDeltaADCDelay(SCK_DELAY_US);
    SigmaDeltaADCDelay(SCK_DELAY_US);
    
	//设置DOUT 输入
	ADC_SDA_INPUT_MODE();
	
	//46 CLK
	SCK_SET; 			
	SigmaDeltaADCDelay(SCK_DELAY_US);	
	SCK_CLR;
	SigmaDeltaADCDelay(SCK_DELAY_US);		
	
	return dat; 	
}

/******************************************************************************
 ** \brief	 SigmaDeltaAdcReadData
 **			 读取ADC数据
 ** \param [in] none
 ** \return  24位ADC数据
 ** \note  
*****************************************************************************/
uint32_t SigmaDeltaAdcReadData(void)
{
	uint8_t i;
	uint32_t  dat;
	dat =0;
	for(i=0;i<24;i++) 
	{
		SCK_SET; 			
		SigmaDeltaADCDelay(SCK_DELAY_US);	
		SCK_CLR;
		SigmaDeltaADCDelay(SCK_DELAY_US);	
		dat = dat<<1;	
		if(DOUT_IS_HIGH) 
			dat |= 1; 		
	}	
	return dat;
}


