/*******************************************************************************
* Copyright (C) 2019 China Micro Semiconductor Limited Company. All Rights Reserved.
*
* This software is owned and published by:
* CMS LLC, No 2609-10, Taurus Plaza, TaoyuanRoad, NanshanDistrict, Shenzhen, China.
*
* BY DOWNLOADING, INSTALLING OR USING THIS SOFTWARE, YOU AGREE TO BE BOUND
* BY ALL THE TERMS AND CONDITIONS OF THIS AGREEMENT.
*
* This software contains source code for use with CMS
* components. This software is licensed by CMS to be adapted only
* for use in systems utilizing CMS components. CMS shall not be
* responsible for misuse or illegal use of this software for devices not
* supported herein. CMS is providing this software "AS IS" and will
* not be responsible for issues arising from incorrect user implementation
* of the software.
*
* This software may be replicated in part or whole for the licensed use,
* with the restriction that this Disclaimer and Copyright notice must be
* included with each copy of this software, whether used in part or whole,
* at all times.
*/

/****************************************************************************/
/** \file app_sigmadelta_adc.c
** 
**
**	History:
**	
*****************************************************************************/
/****************************************************************************/
/*	include files
*****************************************************************************/
#include "app_sigmadelta_adc.h"

/****************************************************************************/
/*	Local pre-processor symbols/macros('#define')
*****************************************************************************/

/****************************************************************************/
/*	Global variable definitions(declared in header file with 'extern')
*****************************************************************************/
SiDaADC_Str   SiDaAdcStr;

/****************************************************************************/
/*	Local type definitions('typedef')
*****************************************************************************/

/****************************************************************************/
/*	Local variable  definitions('static')
*****************************************************************************/

/****************************************************************************/
/*	Local function prototypes('static')
*****************************************************************************/

/****************************************************************************/
/*	Function implementation - global ('extern') and local('static')
*****************************************************************************/

/******************************************************************************
 ** \brief	 app_SigmadeltaADC_Init
 **			 
 ** \param [in] none
 ** \return  none
 ** \note  
*****************************************************************************/
void SigmadeltaADCConfig(void)
{		
	uint16_t Rconfig1,Rconfig2,Rconfig3,Rconfig4;
	
	//LDO
	SiDaAdcStr.Ldo = CMS_SET_LDO_2P6V;
	SiDaAdcStr.LdoBypass = CMS_LDO_BYPASS_ON;	
	SiDaAdcStr.LdoOutProtectEn= CMS_LDO_OUT_PROTECT_ON;

	//Ƶ	
	SiDaAdcStr.AdcFre =  CMS_ADCFRE_656KHZ;
	SiDaAdcStr.SpeedSel = CMS_ADCFRE_656KHZ_SPEED_10HZ;
	
	//ͨ
	SiDaAdcStr.ChannelSet = CMS_CH_SET_CH1;
	SiDaAdcStr.ChannelSel = CMS_CH_SEL_CH;

	//PGA
	SiDaAdcStr.PGASel = CMS_PGA_SEL_128;	

	//
	SiDaAdcStr.Power = CMS_POWER_SEL_LOW;	
	
	SiDaAdcStr.ADCChopFre = CMS_CHOP_ADC_FREDIV_16;	
	SiDaAdcStr.ChopFre = CMS_CHOP_FREDIV_8;		
	SiDaAdcStr.ChopEn = CMS_CHOP_EN;	
	SiDaAdcStr.DeadZone = CMS_DEAD_ZONE_MAX;
	SiDaAdcStr.Trim_OS	= 0x8;
	SiDaAdcStr.Trim_BG	 = 0x5;
	
	
	SiDaAdcStr.Osr = SiDaAdcStr.SpeedSel;
	SiDaAdcStr.Config1 = (SiDaAdcStr.Ldo<<6)|(((SiDaAdcStr.Osr>>1)&0x3)<<4)|
	                     (SiDaAdcStr.ChannelSet<<3)|(SiDaAdcStr.PGASel);
							
	SiDaAdcStr.Config2 =  (SiDaAdcStr.ChannelSel<<5)|(SiDaAdcStr.Power<<4)| 
							 ((SiDaAdcStr.AdcFre)<<3)|((SiDaAdcStr.Osr &0x1)<<2)|
							 (SiDaAdcStr.ChopEn<<1) |(SiDaAdcStr.ADCChopFre<<0);
							
	SiDaAdcStr.Config3 = (SiDaAdcStr.Trim_OS<<4)|(SiDaAdcStr.DeadZone<<3)|(SiDaAdcStr.LdoBypass<<2)
						|(SiDaAdcStr.LdoOutProtectEn<<1);
	
	SiDaAdcStr.Config4 = (SiDaAdcStr.Trim_BG<<4) | (SiDaAdcStr.ChopFre<<0);	
	
	
	//дCONFIG
	SigmaDeltaWaitReady();
	SigmaDeltaAdcWriteReg(CMS_CMD_WRITE_CONFIG1,SiDaAdcStr.Config1);
	SigmaDeltaWaitReady();	
	SigmaDeltaAdcWriteReg(CMS_CMD_WRITE_CONFIG2,SiDaAdcStr.Config2);
	SigmaDeltaWaitReady();
	SigmaDeltaAdcWriteReg(CMS_CMD_WRITE_CONFIG3,SiDaAdcStr.Config3);
	SigmaDeltaWaitReady();
	SigmaDeltaAdcWriteReg(CMS_CMD_WRITE_CONFIG4,SiDaAdcStr.Config4);	
	
	//CONFIG
	SigmaDeltaWaitReady();	
	Rconfig1 = SigmaDeltaAdcReadReg(CMS_CMD_READ_CONFIG1);

	SigmaDeltaWaitReady();	
	Rconfig2 = SigmaDeltaAdcReadReg(CMS_CMD_READ_CONFIG2);

	SigmaDeltaWaitReady();	
	Rconfig3 = SigmaDeltaAdcReadReg(CMS_CMD_READ_CONFIG3);

	SigmaDeltaWaitReady();	
	Rconfig4 = SigmaDeltaAdcReadReg(CMS_CMD_READ_CONFIG4);
	
	printf("SiDaADC Write Config1 :0x%x\n\r",(uint16_t)SiDaAdcStr.Config1);	
	printf("SiDaADC Write Config2 :0x%x\n\r",(uint16_t)SiDaAdcStr.Config2);	
	printf("SiDaADC Write Config3 :0x%x\n\r",(uint16_t)SiDaAdcStr.Config3);	
	printf("SiDaADC Write Config4 :0x%x\n\r",(uint16_t)SiDaAdcStr.Config4);
	
	printf("SiDaADC Read Config1 :0x%x\n\r",Rconfig1);	
	printf("SiDaADC Read Config2 :0x%x\n\r",Rconfig2);	
	printf("SiDaADC Read Config3 :0x%x\n\r",Rconfig3);	
	printf("SiDaADC Read Config4 :0x%x\n\r",Rconfig4);
}
